@@ -3,10 +3,10 @@
 dat <- dat[,c("{user_parms}")]
 names(dat) <- c("case","session","phase","outcome")
 
-dat <- preprocess_SCD(case = case, 
+dat <- preprocess_SCD(design = "{user_design}", 
+                      case = case, 
                       phase = phase, 
                       session = session, 
                       outcome = outcome, 
-                      design = "{user_design}", 
                       data = dat)
 
